@@ -6,17 +6,17 @@
 // Qt
 #include <QtTest>
 // KWin
+#include "../../src/server/compositor_interface.h"
+#include "../../src/server/display.h"
+#include "../../src/server/plasmawindowmanagement_interface.h"
+#include "../../src/server/surface_interface.h"
 #include "KWayland/Client/compositor.h"
 #include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
+#include "KWayland/Client/plasmawindowmanagement.h"
 #include "KWayland/Client/region.h"
 #include "KWayland/Client/registry.h"
 #include "KWayland/Client/surface.h"
-#include "KWayland/Client/plasmawindowmanagement.h"
-#include "../../src/server/display.h"
-#include "../../src/server/compositor_interface.h"
-#include "../../src/server/plasmawindowmanagement_interface.h"
-#include "../../src/server/surface_interface.h"
 #include <wayland-plasma-window-management-client-protocol.h>
 
 typedef void (KWaylandServer::PlasmaWindowInterface::*ServerWindowSignal)();
@@ -122,7 +122,6 @@ void TestWindowManagement::init()
     QSignalSpy windowManagementSpy(m_registry, &KWayland::Client::Registry::plasmaWindowManagementAnnounced);
     QVERIFY(windowManagementSpy.isValid());
 
-
     QVERIFY(!m_registry->eventQueue());
     m_registry->setEventQueue(m_queue);
     QCOMPARE(m_registry->eventQueue(), m_queue);
@@ -134,11 +133,12 @@ void TestWindowManagement::init()
     QVERIFY(compositorSpy.wait());
     m_compositor = m_registry->createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
 
-
     m_windowManagementInterface = new PlasmaWindowManagementInterface(m_display, m_display);
 
     QVERIFY(windowManagementSpy.wait());
-    m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
+    m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(),
+                                                                  windowManagementSpy.first().last().value<quint32>(),
+                                                                  this);
 
     QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.isValid());
@@ -155,7 +155,7 @@ void TestWindowManagement::init()
     QVERIFY(m_surface);
 
     QVERIFY(serverSurfaceCreated.wait());
-    m_surfaceInterface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface*>();
+    m_surfaceInterface = serverSurfaceCreated.first().first().value<KWaylandServer::SurfaceInterface *>();
     QVERIFY(m_surfaceInterface);
 }
 
@@ -188,7 +188,6 @@ void TestWindowManagement::testMinimizedGeometry()
 
 void TestWindowManagement::cleanup()
 {
-
     if (m_surface) {
         delete m_surface;
         m_surface = nullptr;
@@ -283,7 +282,6 @@ void TestWindowManagement::testActiveWindowOnUnmapped()
     m_windowInterface = nullptr;
     QVERIFY(activeWindowChangedSpy.wait());
     QVERIFY(!m_windowManagement->activeWindow());
-
 }
 
 void TestWindowManagement::testDeleteActiveWindow()
@@ -321,7 +319,7 @@ void TestWindowManagement::testCreateAfterUnmap()
     QCOMPARE(m_windowManagementInterface->children().count(), 0);
 
     windowAddedSpy.wait();
-    auto window = dynamic_cast<KWayland::Client::PlasmaWindow*>(m_windowManagement->children().last());
+    auto window = dynamic_cast<KWayland::Client::PlasmaWindow *>(m_windowManagement->children().last());
     QVERIFY(window);
     // now this is not yet on the server, on the server it will be after next roundtrip
     // which we can trigger by waiting for destroy of the newly created window.
@@ -340,8 +338,8 @@ void TestWindowManagement::testRequests_data()
     QTest::addColumn<ServerWindowSignal>("changedSignal");
     QTest::addColumn<ClientWindowVoidSetter>("requester");
 
-    QTest::newRow("close")  << &PlasmaWindowInterface::closeRequested  << &PlasmaWindow::requestClose;
-    QTest::newRow("move")   << &PlasmaWindowInterface::moveRequested   << &PlasmaWindow::requestMove;
+    QTest::newRow("close") << &PlasmaWindowInterface::closeRequested << &PlasmaWindow::requestClose;
+    QTest::newRow("move") << &PlasmaWindowInterface::moveRequested << &PlasmaWindow::requestMove;
     QTest::newRow("resize") << &PlasmaWindowInterface::resizeRequested << &PlasmaWindow::requestResize;
 }
 
@@ -362,7 +360,7 @@ void TestWindowManagement::testRequestsBoolean_data()
     QTest::addColumn<ServerWindowBooleanSignal>("changedSignal");
     QTest::addColumn<int>("flag");
 
-    QTest::newRow("activate")  << &PlasmaWindowInterface::activeRequested  << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
+    QTest::newRow("activate") << &PlasmaWindowInterface::activeRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_ACTIVE);
     QTest::newRow("minimized") << &PlasmaWindowInterface::minimizedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MINIMIZED);
     QTest::newRow("maximized") << &PlasmaWindowInterface::maximizedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MAXIMIZED);
     QTest::newRow("fullscreen") << &PlasmaWindowInterface::fullscreenRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_FULLSCREEN);
@@ -379,7 +377,8 @@ void TestWindowManagement::testRequestsBoolean_data()
     QTest::newRow("shaded") << &PlasmaWindowInterface::shadedRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_SHADED);
     QTest::newRow("movable") << &PlasmaWindowInterface::movableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_MOVABLE);
     QTest::newRow("resizable") << &PlasmaWindowInterface::resizableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_RESIZABLE);
-    QTest::newRow("virtualDesktopChangeable") << &PlasmaWindowInterface::virtualDesktopChangeableRequested << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_VIRTUAL_DESKTOP_CHANGEABLE);
+    QTest::newRow("virtualDesktopChangeable") << &PlasmaWindowInterface::virtualDesktopChangeableRequested
+                                              << int(ORG_KDE_PLASMA_WINDOW_MANAGEMENT_STATE_VIRTUAL_DESKTOP_CHANGEABLE);
 }
 
 void TestWindowManagement::testRequestsBoolean()
@@ -506,7 +505,7 @@ void TestWindowManagement::testParentWindow()
     QScopedPointer<KWaylandServer::PlasmaWindowInterface> serverTransient(m_windowManagementInterface->createWindow(this, QUuid::createUuid()));
     serverTransient->setParentWindow(m_windowInterface);
     QVERIFY(windowAddedSpy.wait());
-    auto transient = windowAddedSpy.first().first().value<PlasmaWindow*>();
+    auto transient = windowAddedSpy.first().first().value<PlasmaWindow *>();
     QCOMPARE(transient->parentWindow().data(), parentWindow);
 
     // let's unset the parent
@@ -552,8 +551,9 @@ void TestWindowManagement::testGeometry()
     QCOMPARE(m_window->geometry(), QRect(0, 0, 35, 45));
 
     // let's bind a second PlasmaWindowManagement to verify the initial setting
-    QScopedPointer<PlasmaWindowManagement> pm(m_registry->createPlasmaWindowManagement(m_registry->interface(Registry::Interface::PlasmaWindowManagement).name,
-                                                                                       m_registry->interface(Registry::Interface::PlasmaWindowManagement).version));
+    QScopedPointer<PlasmaWindowManagement> pm(
+        m_registry->createPlasmaWindowManagement(m_registry->interface(Registry::Interface::PlasmaWindowManagement).name,
+                                                 m_registry->interface(Registry::Interface::PlasmaWindowManagement).version));
     QVERIFY(!pm.isNull());
     QSignalSpy windowAddedSpy(pm.data(), &PlasmaWindowManagement::windowCreated);
     QVERIFY(windowAddedSpy.isValid());
@@ -596,11 +596,11 @@ void TestWindowManagement::testPid()
     QVERIFY(m_window);
     QVERIFY(m_window->pid() == 1337);
 
-    //test server not setting a PID for whatever reason
+    // test server not setting a PID for whatever reason
     QScopedPointer<KWaylandServer::PlasmaWindowInterface> newWindowInterface(m_windowManagementInterface->createWindow(this, QUuid::createUuid()));
     QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.wait());
-    QScopedPointer<PlasmaWindow> newWindow( windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>());
+    QScopedPointer<PlasmaWindow> newWindow(windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>());
     QVERIFY(newWindow);
     QVERIFY(newWindow->pid() == 0);
 }
