@@ -12,12 +12,10 @@
 #include <KWaylandServer/kwaylandserver_export.h>
 
 struct wl_client;
-struct wl_interface;
 struct wl_resource;
 
 namespace KWaylandServer
 {
-
 class ClientConnectionPrivate;
 class Display;
 
@@ -40,21 +38,10 @@ public:
      * Flushes the connection to this client. Ensures that all events are pushed to the client.
      */
     void flush();
-    /**
-     * Creates a new wl_resource for the provided @p interface.
-     *
-     * Thus a convenient wrapper around wl_resource_create
-     *
-     * @param interface
-     * @param version
-     * @param id
-     * @returns the created native wl_resource
-     */
-    wl_resource *createResource(const wl_interface *interface, quint32 version, quint32 id);
     /**
      * Get the wl_resource associated with the given @p id.
      */
-    wl_resource *getResource(quint32 id);
+    wl_resource *getResource(quint32 id) const;
 
     /**
      * @returns the native wl_client this ClientConnection represents.
@@ -108,11 +95,11 @@ public:
     /**
      * Cast operator the native wl_client this ClientConnection represents.
      */
-    operator wl_client*();
+    operator wl_client *();
     /**
      * Cast operator the native wl_client this ClientConnection represents.
      */
-    operator wl_client*() const;
+    operator wl_client *() const;
 
     /**
      * Destroys this ClientConnection.
@@ -130,7 +117,7 @@ Q_SIGNALS:
     /**
      * Signal emitted when the ClientConnection got disconnected from the server.
      */
-    void disconnected(KWaylandServer::ClientConnection*);
+    void disconnected(KWaylandServer::ClientConnection *);
 
 private:
     friend class Display;
@@ -140,4 +127,4 @@ private:
 
 }
 
-Q_DECLARE_METATYPE(KWaylandServer::ClientConnection*)
+Q_DECLARE_METATYPE(KWaylandServer::ClientConnection *)
