@@ -19,8 +19,7 @@
 
 namespace KWaylandServer
 {
-
-static const quint32 s_version = 1;
+static const quint32 s_version = 2;
 
 class OutputDeviceV2InterfacePrivate : public QtWaylandServer::kde_output_device_v2
 {
@@ -29,16 +28,6 @@ public:
     ~OutputDeviceV2InterfacePrivate() override;
 
     void updateGeometry();
-    void updateUuid();
-    void updateEdid();
-    void updateEnabled();
-    void updateScale();
-    void updateEisaId();
-    void updateSerialNumber();
-    void updateCapabilities();
-    void updateOverscan();
-    void updateVrrPolicy();
-    void updateRgbRange();
 
     void sendGeometry(Resource *resource);
     wl_resource *sendNewMode(Resource *resource, OutputDeviceModeV2Interface *mode);
@@ -49,6 +38,7 @@ public:
     void sendEnabled(Resource *resource);
     void sendScale(Resource *resource);
     void sendEisaId(Resource *resource);
+    void sendName(Resource *resource);
     void sendSerialNumber(Resource *resource);
     void sendCapabilities(Resource *resource);
     void sendOverscan(Resource *resource);
@@ -62,6 +52,7 @@ public:
     qreal scale = 1.0;
     QString serialNumber;
     QString eisaId;
+    QString name;
     OutputDeviceV2Interface::SubPixel subPixel = OutputDeviceV2Interface::SubPixel::Unknown;
     OutputDeviceV2Interface::Transform transform = OutputDeviceV2Interface::Transform::Normal;
 
@@ -136,12 +127,6 @@ OutputDeviceV2Interface::OutputDeviceV2Interface(Display *display, QObject *pare
     : QObject(parent)
     , d(new OutputDeviceV2InterfacePrivate(this, display))
 {
-    connect(this, &OutputDeviceV2Interface::subPixelChanged,       this, [this] { d->updateGeometry(); });
-    connect(this, &OutputDeviceV2Interface::transformChanged,      this, [this] { d->updateGeometry(); });
-    connect(this, &OutputDeviceV2Interface::globalPositionChanged, this, [this] { d->updateGeometry(); });
-    connect(this, &OutputDeviceV2Interface::modelChanged,          this, [this] { d->updateGeometry(); });
-    connect(this, &OutputDeviceV2Interface::manufacturerChanged,   this, [this] { d->updateGeometry(); });
-    connect(this, &OutputDeviceV2Interface::scaleChanged,         this, [this] { d->updateScale(); });
 }
 
 OutputDeviceV2Interface::~OutputDeviceV2Interface()
@@ -198,8 +183,7 @@ void OutputDeviceV2Interface::setCurrentMode(OutputDeviceModeV2Interface *mode)
         d->sendCurrentMode(resource, d->currentMode);
         d->sendDone(resource);
     }
-
-    Q_EMIT currentModeChanged();
+    d->updateGeometry();
 }
 
 bool OutputDeviceV2Interface::setCurrentMode(const QSize &size, int refreshRate)
@@ -270,6 +254,7 @@ void OutputDeviceV2InterfacePrivate::kde_output_device_v2_bind_resource(Resource
     sendGeometry(resource);
     sendScale(resource);
     sendEisaId(resource);
+    sendName(resource);
     sendSerialNumber(resource);
 
     auto currentModeIt = modes.end();
@@ -345,6 +330,13 @@ void OutputDeviceV2InterfacePrivate::sendEisaId(Resource *resource)
     send_eisa_id(resource->handle, eisaId);
 }
 
+void OutputDeviceV2InterfacePrivate::sendName(Resource *resource)
+{
+    if (resource->version() >= KDE_OUTPUT_DEVICE_V2_NAME_SINCE_VERSION) {
+        send_name(resource->handle, name);
+    }
+}
+
 void OutputDeviceV2InterfacePrivate::sendDone(Resource *resource)
 {
     send_done(resource->handle);
@@ -353,28 +345,18 @@ void OutputDeviceV2InterfacePrivate::sendDone(Resource *resource)
 void OutputDeviceV2InterfacePrivate::updateGeometry()
 {
     const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
+    for (const auto &resource : clientResources) {
         sendGeometry(resource);
         sendDone(resource);
     }
 }
 
-void OutputDeviceV2InterfacePrivate::updateScale()
-{
-    const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
-        sendScale(resource);
-        sendDone(resource);
-    }
-}
-
 void OutputDeviceV2Interface::setPhysicalSize(const QSize &arg)
 {
     if (d->physicalSize == arg) {
         return;
     }
     d->physicalSize = arg;
-    Q_EMIT physicalSizeChanged(d->physicalSize);
 }
 
 void OutputDeviceV2Interface::setGlobalPosition(const QPoint &arg)
@@ -383,7 +365,7 @@ void OutputDeviceV2Interface::setGlobalPosition(const QPoint &arg)
         return;
     }
     d->globalPosition = arg;
-    Q_EMIT globalPositionChanged(d->globalPosition);
+    d->updateGeometry();
 }
 
 void OutputDeviceV2Interface::setManufacturer(const QString &arg)
@@ -392,7 +374,6 @@ void OutputDeviceV2Interface::setManufacturer(const QString &arg)
         return;
     }
     d->manufacturer = arg;
-    Q_EMIT manufacturerChanged(d->manufacturer);
 }
 
 void OutputDeviceV2Interface::setModel(const QString &arg)
@@ -401,7 +382,6 @@ void OutputDeviceV2Interface::setModel(const QString &arg)
         return;
     }
     d->model = arg;
-    Q_EMIT modelChanged(d->model);
 }
 
 void OutputDeviceV2Interface::setSerialNumber(const QString &arg)
@@ -410,7 +390,6 @@ void OutputDeviceV2Interface::setSerialNumber(const QString &arg)
         return;
     }
     d->serialNumber = arg;
-    Q_EMIT serialNumberChanged(d->serialNumber);
 }
 
 void OutputDeviceV2Interface::setEisaId(const QString &arg)
@@ -419,7 +398,14 @@ void OutputDeviceV2Interface::setEisaId(const QString &arg)
         return;
     }
     d->eisaId = arg;
-    Q_EMIT eisaIdChanged(d->eisaId);
+}
+
+void OutputDeviceV2Interface::setName(const QString &arg)
+{
+    if (d->name == arg) {
+        return;
+    }
+    d->name = arg;
 }
 
 void OutputDeviceV2Interface::setSubPixel(SubPixel arg)
@@ -428,7 +414,7 @@ void OutputDeviceV2Interface::setSubPixel(SubPixel arg)
         return;
     }
     d->subPixel = arg;
-    Q_EMIT subPixelChanged(d->subPixel);
+    d->updateGeometry();
 }
 
 void OutputDeviceV2Interface::setTransform(Transform arg)
@@ -437,7 +423,7 @@ void OutputDeviceV2Interface::setTransform(Transform arg)
         return;
     }
     d->transform = arg;
-    Q_EMIT transformChanged(d->transform);
+    d->updateGeometry();
 }
 
 void OutputDeviceV2Interface::setScale(qreal scale)
@@ -446,7 +432,11 @@ void OutputDeviceV2Interface::setScale(qreal scale)
         return;
     }
     d->scale = scale;
-    Q_EMIT scaleChanged(d->scale);
+    const auto clientResources = d->resourceMap();
+    for (const auto &resource : clientResources) {
+        d->sendScale(resource);
+        d->sendDone(resource);
+    }
 }
 
 QSize OutputDeviceV2Interface::physicalSize() const
@@ -479,6 +469,11 @@ QString OutputDeviceV2Interface::eisaId() const
     return d->eisaId;
 }
 
+QString OutputDeviceV2Interface::name() const
+{
+    return d->name;
+}
+
 qreal OutputDeviceV2Interface::scale() const
 {
     return d->scale;
@@ -505,8 +500,6 @@ void OutputDeviceV2Interface::setModes(const QList<OutputDeviceModeV2Interface *
 
     const auto oldModes = d->modes;
     d->modes.clear();
-
-    const auto oldCurrentMode = d->currentMode;
     d->currentMode = nullptr;
 
     for (OutputDeviceModeV2Interface *outputDeviceMode : modes) {
@@ -536,19 +529,16 @@ void OutputDeviceV2Interface::setModes(const QList<OutputDeviceModeV2Interface *
     for (auto resource : clientResources) {
         d->sendDone(resource);
     }
-
-    if (oldCurrentMode != d->currentMode) {
-        Q_EMIT currentModeChanged();
-    }
-
-    Q_EMIT modesChanged();
 }
 
 void OutputDeviceV2Interface::setEdid(const QByteArray &edid)
 {
     d->edid = edid;
-    d->updateEdid();
-    Q_EMIT edidChanged();
+    const auto clientResources = d->resourceMap();
+    for (const auto &resource : clientResources) {
+        d->sendEdid(resource);
+        d->sendDone(resource);
+    }
 }
 
 QByteArray OutputDeviceV2Interface::edid() const
@@ -560,8 +550,11 @@ void OutputDeviceV2Interface::setEnabled(bool enabled)
 {
     if (d->enabled != enabled) {
         d->enabled = enabled;
-        d->updateEnabled();
-        Q_EMIT enabledChanged();
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendEnabled(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -574,8 +567,11 @@ void OutputDeviceV2Interface::setUuid(const QUuid &uuid)
 {
     if (d->uuid != uuid) {
         d->uuid = uuid;
-        d->updateUuid();
-        Q_EMIT uuidChanged();
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendUuid(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -599,42 +595,6 @@ void OutputDeviceV2InterfacePrivate::sendUuid(Resource *resource)
     send_uuid(resource->handle, uuid.toString(QUuid::WithoutBraces));
 }
 
-void OutputDeviceV2InterfacePrivate::updateEnabled()
-{
-    const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
-        sendEnabled(resource);
-        sendDone(resource);
-    }
-}
-
-void OutputDeviceV2InterfacePrivate::updateEdid()
-{
-    const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
-        sendEdid(resource);
-        sendDone(resource);
-    }
-}
-
-void OutputDeviceV2InterfacePrivate::updateUuid()
-{
-    const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
-        sendUuid(resource);
-        sendDone(resource);
-    }
-}
-
-void OutputDeviceV2InterfacePrivate::updateEisaId()
-{
-    const auto clientResources = resourceMap();
-    for (auto resource : clientResources) {
-        sendEisaId(resource);
-        sendDone(resource);
-    }
-}
-
 uint32_t OutputDeviceV2Interface::overscan() const
 {
     return d->overscan;
@@ -649,8 +609,11 @@ void OutputDeviceV2Interface::setCapabilities(Capabilities cap)
 {
     if (d->capabilities != cap) {
         d->capabilities = cap;
-        d->updateCapabilities();
-        Q_EMIT capabilitiesChanged();
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendCapabilities(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -659,21 +622,15 @@ void OutputDeviceV2InterfacePrivate::sendCapabilities(Resource *resource)
     send_capabilities(resource->handle, static_cast<uint32_t>(capabilities));
 }
 
-void OutputDeviceV2InterfacePrivate::updateCapabilities()
-{
-    const auto clientResources = resourceMap();
-    for (const auto &resource : clientResources) {
-        sendCapabilities(resource);
-        sendDone(resource);
-    }
-}
-
 void OutputDeviceV2Interface::setOverscan(uint32_t overscan)
 {
     if (d->overscan != overscan) {
         d->overscan = overscan;
-        d->updateOverscan();
-        Q_EMIT overscanChanged();
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendOverscan(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -682,15 +639,6 @@ void OutputDeviceV2InterfacePrivate::sendOverscan(Resource *resource)
     send_overscan(resource->handle, static_cast<uint32_t>(overscan));
 }
 
-void OutputDeviceV2InterfacePrivate::updateOverscan()
-{
-    const auto clientResources = resourceMap();
-    for (const auto &resource : clientResources) {
-        sendOverscan(resource);
-        sendDone(resource);
-    }
-}
-
 void OutputDeviceV2InterfacePrivate::sendVrrPolicy(Resource *resource)
 {
     send_vrr_policy(resource->handle, static_cast<uint32_t>(vrrPolicy));
@@ -705,17 +653,11 @@ void OutputDeviceV2Interface::setVrrPolicy(VrrPolicy policy)
 {
     if (d->vrrPolicy != policy) {
         d->vrrPolicy = policy;
-        d->updateVrrPolicy();
-        Q_EMIT vrrPolicyChanged();
-    }
-}
-
-void OutputDeviceV2InterfacePrivate::updateVrrPolicy()
-{
-    const auto clientResources = resourceMap();
-    for (const auto &resource : clientResources) {
-        sendVrrPolicy(resource);
-        sendDone(resource);
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendVrrPolicy(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -728,8 +670,11 @@ void OutputDeviceV2Interface::setRgbRange(RgbRange rgbRange)
 {
     if (d->rgbRange != rgbRange) {
         d->rgbRange = rgbRange;
-        d->updateRgbRange();
-        Q_EMIT rgbRangeChanged();
+        const auto clientResources = d->resourceMap();
+        for (const auto &resource : clientResources) {
+            d->sendRgbRange(resource);
+            d->sendDone(resource);
+        }
     }
 }
 
@@ -738,13 +683,9 @@ void OutputDeviceV2InterfacePrivate::sendRgbRange(Resource *resource)
     send_rgb_range(resource->handle, static_cast<uint32_t>(rgbRange));
 }
 
-void OutputDeviceV2InterfacePrivate::updateRgbRange()
+wl_resource *OutputDeviceV2Interface::resource() const
 {
-    const auto clientResources = resourceMap();
-    for (const auto &resource : clientResources) {
-        sendRgbRange(resource);
-        sendDone(resource);
-    }
+    return d->resource()->handle;
 }
 
 OutputDeviceV2Interface *OutputDeviceV2Interface::get(wl_resource *native)
