@@ -5,8 +5,8 @@
 */
 #include "server_decoration_palette_interface.h"
 #include "display.h"
-#include "surface_interface.h"
 #include "logging.h"
+#include "surface_interface.h"
 
 #include <QtGlobal>
 
@@ -14,7 +14,6 @@
 
 namespace KWaylandServer
 {
-
 static const quint32 s_version = 1;
 
 class ServerSideDecorationPaletteManagerInterfacePrivate : public QtWaylandServer::org_kde_kwin_server_decoration_palette_manager
@@ -22,15 +21,16 @@ class ServerSideDecorationPaletteManagerInterfacePrivate : public QtWaylandServe
 public:
     ServerSideDecorationPaletteManagerInterfacePrivate(ServerSideDecorationPaletteManagerInterface *q, Display *display);
 
-    QVector<ServerSideDecorationPaletteInterface*> palettes;
+    QVector<ServerSideDecorationPaletteInterface *> palettes;
     ServerSideDecorationPaletteManagerInterface *q;
 
 protected:
     void org_kde_kwin_server_decoration_palette_manager_create(Resource *resource, uint32_t id, struct ::wl_resource *surface) override;
-
 };
 
-void ServerSideDecorationPaletteManagerInterfacePrivate::org_kde_kwin_server_decoration_palette_manager_create(Resource *resource, uint32_t id, wl_resource *surface)
+void ServerSideDecorationPaletteManagerInterfacePrivate::org_kde_kwin_server_decoration_palette_manager_create(Resource *resource,
+                                                                                                               uint32_t id,
+                                                                                                               wl_resource *surface)
 {
     SurfaceInterface *s = SurfaceInterface::get(surface);
     if (!s) {
@@ -38,7 +38,7 @@ void ServerSideDecorationPaletteManagerInterfacePrivate::org_kde_kwin_server_dec
         qCWarning(KWAYLAND_SERVER) << "ServerSideDecorationPaletteInterface requested for non existing SurfaceInterface";
         return;
     }
-   
+
     wl_resource *palette_resource = wl_resource_create(resource->client(), &org_kde_kwin_server_decoration_palette_interface, resource->version(), id);
     if (!palette_resource) {
         wl_client_post_no_memory(resource->client());
@@ -53,7 +53,8 @@ void ServerSideDecorationPaletteManagerInterfacePrivate::org_kde_kwin_server_dec
     Q_EMIT q->paletteCreated(palette);
 }
 
-ServerSideDecorationPaletteManagerInterfacePrivate::ServerSideDecorationPaletteManagerInterfacePrivate(ServerSideDecorationPaletteManagerInterface *_q, Display *display)
+ServerSideDecorationPaletteManagerInterfacePrivate::ServerSideDecorationPaletteManagerInterfacePrivate(ServerSideDecorationPaletteManagerInterface *_q,
+                                                                                                       Display *display)
     : QtWaylandServer::org_kde_kwin_server_decoration_palette_manager(*display, s_version)
     , q(_q)
 {
@@ -114,7 +115,9 @@ void ServerSideDecorationPaletteInterfacePrivate::org_kde_kwin_server_decoration
     delete q;
 }
 
-ServerSideDecorationPaletteInterfacePrivate::ServerSideDecorationPaletteInterfacePrivate(ServerSideDecorationPaletteInterface *_q, SurfaceInterface *surface, wl_resource *resource)
+ServerSideDecorationPaletteInterfacePrivate::ServerSideDecorationPaletteInterfacePrivate(ServerSideDecorationPaletteInterface *_q,
+                                                                                         SurfaceInterface *surface,
+                                                                                         wl_resource *resource)
     : QtWaylandServer::org_kde_kwin_server_decoration_palette(resource)
     , surface(surface)
     , q(_q)
@@ -134,10 +137,9 @@ QString ServerSideDecorationPaletteInterface::palette() const
     return d->palette;
 }
 
-SurfaceInterface* ServerSideDecorationPaletteInterface::surface() const
+SurfaceInterface *ServerSideDecorationPaletteInterface::surface() const
 {
     return d->surface;
 }
 
-}//namespace
-
+} // namespace
