@@ -10,6 +10,7 @@
 #include "compositor_interface.h"
 #include "display.h"
 #include "idleinhibit_v1_interface_p.h"
+#include "linuxdmabufv1clientbuffer.h"
 #include "pointerconstraints_v1_interface_p.h"
 #include "region_interface_p.h"
 #include "subcompositor_interface.h"
@@ -434,8 +435,17 @@ QMatrix4x4 SurfaceInterfacePrivate::buildSurfaceToBufferMatrix()
 
     if (current.viewport.sourceGeometry.isValid()) {
         surfaceToBufferMatrix.translate(current.viewport.sourceGeometry.x(), current.viewport.sourceGeometry.y());
-        surfaceToBufferMatrix.scale(current.viewport.sourceGeometry.width() / surfaceSize.width(),
-                                    current.viewport.sourceGeometry.height() / surfaceSize.height());
+    }
+
+    QSizeF sourceSize;
+    if (current.viewport.sourceGeometry.isValid()) {
+        sourceSize = current.viewport.sourceGeometry.size();
+    } else {
+        sourceSize = implicitSurfaceSize;
+    }
+
+    if (sourceSize != surfaceSize) {
+        surfaceToBufferMatrix.scale(sourceSize.width() / surfaceSize.width(), sourceSize.height() / surfaceSize.height());
     }
 
     return surfaceToBufferMatrix;
@@ -546,28 +556,32 @@ void SurfaceInterfacePrivate::applyState(SurfaceState *next)
     // TODO: Refactor the state management code because it gets more clumsy.
     if (current.buffer) {
         bufferSize = current.buffer->size();
+
+        implicitSurfaceSize = current.buffer->size() / current.bufferScale;
+        switch (current.bufferTransform) {
+        case OutputInterface::Transform::Rotated90:
+        case OutputInterface::Transform::Rotated270:
+        case OutputInterface::Transform::Flipped90:
+        case OutputInterface::Transform::Flipped270:
+            implicitSurfaceSize.transpose();
+            break;
+        case OutputInterface::Transform::Normal:
+        case OutputInterface::Transform::Rotated180:
+        case OutputInterface::Transform::Flipped:
+        case OutputInterface::Transform::Flipped180:
+            break;
+        }
+
         if (current.viewport.destinationSize.isValid()) {
             surfaceSize = current.viewport.destinationSize;
         } else if (current.viewport.sourceGeometry.isValid()) {
             surfaceSize = current.viewport.sourceGeometry.size().toSize();
         } else {
-            surfaceSize = current.buffer->size() / current.bufferScale;
-            switch (current.bufferTransform) {
-            case OutputInterface::Transform::Rotated90:
-            case OutputInterface::Transform::Rotated270:
-            case OutputInterface::Transform::Flipped90:
-            case OutputInterface::Transform::Flipped270:
-                surfaceSize.transpose();
-                break;
-            case OutputInterface::Transform::Normal:
-            case OutputInterface::Transform::Rotated180:
-            case OutputInterface::Transform::Flipped:
-            case OutputInterface::Transform::Flipped180:
-                break;
-            }
+            surfaceSize = implicitSurfaceSize;
         }
     } else {
         surfaceSize = QSize();
+        implicitSurfaceSize = QSize();
         bufferSize = QSize();
     }
 
@@ -936,6 +950,11 @@ bool SurfaceInterface::inhibitsIdle() const
     return !d->idleInhibitors.isEmpty();
 }
 
+LinuxDmaBufV1Feedback *SurfaceInterface::dmabufFeedbackV1() const
+{
+    return d->dmabufFeedbackV1.data();
+}
+
 QPointF SurfaceInterface::mapToBuffer(const QPointF &point) const
 {
     return d->surfaceToBufferMatrix.map(point);
