@@ -37,15 +37,17 @@ public:
     void sendEnter(SurfaceInterface *surface, quint32 serial);
     void sendLeave(quint32 serial, SurfaceInterface *surface);
     void preEdit(const QString &text, const QString &commit);
+    void preEditStyling(uint32_t index, uint32_t length, uint32_t style);
     void commitString(const QString &text);
     void deleteSurroundingText(quint32 beforeLength, quint32 afterLength);
     void setTextDirection(Qt::LayoutDirection direction);
     void setPreEditCursor(qint32 index);
     void setCursorPosition(qint32 index, qint32 anchor);
-    void keysymPressed(quint32 keysym, Qt::KeyboardModifiers modifiers);
-    void keysymReleased(quint32 keysym, Qt::KeyboardModifiers modifiers);
+    void keysymPressed(quint32 keysym, quint32 modifiers);
+    void keysymReleased(quint32 keysym, quint32 modifiers);
     void sendInputPanelState();
     void sendLanguage();
+    void sendModifiersMap();
 
     QList<Resource *> textInputsForClient(ClientConnection *client) const;
     static TextInputV2InterfacePrivate *get(TextInputV2Interface *inputInterface)
@@ -65,6 +67,7 @@ public:
     bool inputPanelVisible = false;
     QRect overlappedSurfaceArea;
     QString language;
+    QByteArray modifiersMap;
     TextInputV2Interface *q;
     QSet<SurfaceInterface *> m_enabledSurfaces;
 
